@@ -156,8 +156,8 @@ class FakeNetworkPollerGrpcClient(NetworkPollerGrpcClient):
         self.fut.set_result(messages)
         self.fut = None
 
-    async def post(self, msg):
-        await super().post(msg)
+    async def post(self, msg, id_key=None):
+        await super().post(msg, id_key)
         fut = self.fut or asyncio.get_event_loop().create_future()
         self.fut = fut
         return fut
