@@ -57,6 +57,10 @@ async def http_probe(host, http_client_cls, methods=('https', 'http'), ports=Non
 
     async def handler(response):
         if 200 <= response.status <= 400:  # accept a redirect, its listening.
+            if response.status == 302 and response.request_info.url.scheme == 'http':
+                loc = response.headers.get('location')
+                if loc and loc.startswith('https'):
+                    return False
             return True
         return False
 
@@ -74,7 +78,7 @@ async def http_probe(host, http_client_cls, methods=('https', 'http'), ports=Non
                                                                allow_redirects=False,
                                                                handler=handler) for x in clients],
                 return_exceptions=True)):
-            if not result and not isinstance(r, Exception):
+            if r and not result and not isinstance(r, Exception):
                 result = clients[i]
             else:
                 await clients[i].close()
